@@ -8,6 +8,7 @@ class MigrationError(Exception):
 
 def handle_migration_error(e: Exception):
     log: logging.Logger = logging.getLogger()
-    log.error("%s: %s" % (type(e).__name__, e))
+    log.error('%s: %s' % (type(e).__name__, e))
     if log.level == logging.DEBUG:
         traceback.print_exc()
+    exit(1)
